=============
API Reference
=============

:Release: |version|
:Date: |today|

This shows the details of the API of the Atmospheric data Community Toolkit. Documentation 
of each procedure in each module is provided as a reference.

.. toctree::
   :maxdepth: 3

   corrections
   discovery
   io
   plotting
   qc
   retrievals
   utils

